@@ -274,8 +274,7 @@ public:
     AgendaItem::List agendaItems(const QString &uid) const;
 
     // insertAtDateTime is in the view's timezone
-    void insertIncidence(const KCalCore::Incidence::Ptr &, const QDateTime &recurrenceId,
-                         const QDateTime &insertAtDateTime, bool createSelected);
+    void insertIncidence(const KCalCore::Incidence::Ptr &, const QDateTime &recurrenceId, const QDateTime &insertAtDateTime, bool createSelected);
     void reevaluateIncidence(const KCalCore::Incidence::Ptr &incidence);
 
     bool datesEqual(const KCalCore::Incidence::Ptr &one, const KCalCore::Incidence::Ptr &two) const;
@@ -294,8 +293,7 @@ protected:
     /* reimplemented from KCalCore::Calendar::CalendarObserver */
     void calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence) override;
     void calendarIncidenceChanged(const KCalCore::Incidence::Ptr &incidence) override;
-    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence,
-                                  const KCalCore::Calendar *calendar) override;
+    void calendarIncidenceDeleted(const KCalCore::Incidence::Ptr &incidence, const KCalCore::Calendar *calendar) override;
 private:
     //quiet --overloaded-virtual warning
     using KCalCore::Calendar::CalendarObserver::calendarIncidenceDeleted;
@@ -351,8 +349,8 @@ bool AgendaView::Private::mightBeVisible(const KCalCore::Incidence::Ptr &inciden
 
     if (!incidence->recurs()) {
         // If DTEND/DTDUE is before the 1st visible column
-        if (incidence->dateTime(KCalCore::Incidence::RoleEnd).date().daysTo(mSelectedDates.first())
-            > 2) {
+        const QDate tdate = incidence->dateTime(KCalCore::Incidence::RoleEnd).date();
+        if (tdate.daysTo(mSelectedDates.first()) > 2) {
             return false;
         }
 
@@ -386,7 +384,9 @@ QList<QDate> AgendaView::Private::generateDateList(const QDate &start, const QDa
 {
     QList<QDate> list;
 
-    if (start.isValid() && end.isValid() && end >= start
+    if (start.isValid()
+        && end.isValid()
+        && end >= start
         && start.daysTo(end) < AgendaView::MAX_DAY_COUNT) {
         QDate date = start;
         list.reserve(start.daysTo(end) + 1);
@@ -714,16 +714,14 @@ void AgendaView::Private::insertIncidence(const KCalCore::Incidence::Ptr &incide
 
 ////////////////////////////////////////////////////////////////////////////
 
-AgendaView::AgendaView(const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide,
-                       QWidget *parent)
+AgendaView::AgendaView(const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide, QWidget *parent)
     : EventView(parent)
     , d(new Private(this, isInteractive, isSideBySide))
 {
     init(start, end);
 }
 
-AgendaView::AgendaView(const PrefsPtr &prefs, const QDate &start, const QDate &end,
-                       bool isInteractive, bool isSideBySide, QWidget *parent)
+AgendaView::AgendaView(const PrefsPtr &prefs, const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide, QWidget *parent)
     : EventView(parent)
     , d(new Private(this, isInteractive, isSideBySide))
 {
@@ -918,7 +916,10 @@ void AgendaView::connectAgenda(Agenda *agenda, Agenda *otherAgenda)
             this, &AgendaView::slotDeleteIncidence);
 
     // drag signals
-    connect(agenda, &Agenda::startDragSignal, this, [this](const KCalCore::Incidence::Ptr &ptr) { startDrag(ptr); });
+    connect(agenda, &Agenda::startDragSignal,
+            this, [this](const KCalCore::Incidence::Ptr &ptr) {
+        startDrag(ptr);
+    });
 
     // synchronize selections
     connect(agenda, &Agenda::incidenceSelected,
@@ -941,8 +942,7 @@ void AgendaView::slotIncidenceSelected(const KCalCore::Incidence::Ptr &incidence
     }
 }
 
-void AgendaView::slotShowIncidencePopup(const KCalCore::Incidence::Ptr &incidence,
-                                        const QDate &date)
+void AgendaView::slotShowIncidencePopup(const KCalCore::Incidence::Ptr &incidence, const QDate &date)
 {
     Akonadi::Item item = d->mViewCalendar->item(incidence);
     //qDebug() << "wanna see the popup for " << incidence->uid() << item.id();
@@ -1135,8 +1135,7 @@ void AgendaView::placeDecorationsFrame(QFrame *frame, bool decorationsFound, boo
     }
 }
 
-void AgendaView::placeDecorations(DecorationList &decoList, const QDate &date, QWidget *labelBox,
-                                  bool forWeek)
+void AgendaView::placeDecorations(DecorationList &decoList, const QDate &date, QWidget *labelBox, bool forWeek)
 {
     foreach (CalendarDecoration::Decoration *deco, decoList) {
         CalendarDecoration::Element::List elements;
@@ -1241,7 +1240,7 @@ void AgendaView::createDayLabels(bool force)
         QString veryLongStr = QLocale::system().toString(date, QLocale::LongFormat);
         QString longstr = i18nc("short_weekday short_monthname date (e.g. Mon Aug 13)", "%1 %2 %3",
                                 QLocale::system().dayName(dW, QLocale::ShortFormat),
-                                QDate::shortMonthName(date.month()),
+                                QLocale::system().monthName(date.month(), QLocale::ShortFormat),
                                 date.day());
         QString shortstr = QString::number(date.day());
 
@@ -1469,12 +1468,12 @@ void AgendaView::updateTimeBarWidth()
     int width = d->mTimeLabelsZone->preferedTimeLabelsWidth();
     for (QLabel *l : qAsConst(d->mTimeBarHeaders)) {
         foreach (const QString &word, l->text().split(QLatin1Char(' '))) {
-            width = qMax(width, fm.width(word));
+            width = qMax(width, fm.boundingRect(word).width());
         }
     }
     setFont(oldFont);
 
-    width = width + fm.width(QLatin1Char('/'));
+    width = width + fm.boundingRect(QLatin1Char('/')).width();
 
     const int timeBarWidth = width * d->mTimeBarHeaders.count();
 
@@ -1485,8 +1484,7 @@ void AgendaView::updateTimeBarWidth()
     }
 }
 
-void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence,
-                                  Akonadi::Collection::Id collectionId)
+void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::Collection::Id collectionId)
 {
     qCDebug(CALENDARVIEW_LOG) << item->text()
                               << "; item->cellXLeft(): " << item->cellXLeft()
@@ -1694,7 +1692,9 @@ void AgendaView::showDates(const QDate &start, const QDate &end, const QDate &pr
         return;
     }
 
-    if (!start.isValid() || !end.isValid() || start > end
+    if (!start.isValid()
+        || !end.isValid()
+        || start > end
         || start.daysTo(end) > MAX_DAY_COUNT) {
         qCWarning(CALENDARVIEW_LOG) << "got bizare parameters: " << start << end
                                     << " - aborting here";
@@ -1800,8 +1800,8 @@ void AgendaView::fillAgenda()
 
     foreach (const KCalCore::Incidence::Ptr &incidence, incidences) {
         Q_ASSERT(incidence);
-        const bool wasSelected = incidence->uid() == selectedAgendaId
-                                 || incidence->uid() == selectedAllDayAgendaId;
+        const bool wasSelected = (incidence->uid() == selectedAgendaId)
+                                 || (incidence->uid() == selectedAllDayAgendaId);
 
         if ((incidence->allDay() && d->mUpdateAllDayAgenda)
             || (!incidence->allDay() && d->mUpdateAgenda)) {
@@ -1892,7 +1892,6 @@ bool AgendaView::displayIncidence(const KCalCore::Incidence::Ptr &incidence, boo
         }
     } else {
         QDateTime dateToAdd; // date to add to our date list
-        QDateTime incidenceStart;
         QDateTime incidenceEnd;
 
         if (todo && todo->hasDueDate() && !todo->isOverdue()) {
@@ -1981,7 +1980,8 @@ void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &g
     Q_UNUSED(gpos);
     Q_UNUSED(allDay);
 
-#ifdef AKONADI_PORT_DISABLED // one item -> multiple items, Incidence* -> akonadi item url (we might have to fetch the items here first!)
+#ifdef AKONADI_PORT_DISABLED // one item -> multiple items, Incidence* -> akonadi item url
+                             // (we might have to fetch the items here first!)
     if (gpos.x() < 0 || gpos.y() < 0) {
         return;
     }
@@ -2023,8 +2023,7 @@ void AgendaView::slotIncidencesDropped(const QList<QUrl> &items, const QPoint &g
 #endif
 }
 
-void AgendaView::slotIncidencesDropped(const KCalCore::Incidence::List &incidences,
-                                       const QPoint &gpos, bool allDay)
+void AgendaView::slotIncidencesDropped(const KCalCore::Incidence::List &incidences, const QPoint &gpos, bool allDay)
 {
     if (gpos.x() < 0 || gpos.y() < 0) {
         return;
@@ -2035,9 +2034,9 @@ void AgendaView::slotIncidencesDropped(const KCalCore::Incidence::List &incidenc
 
     Q_FOREACH (const KCalCore::Incidence::Ptr &incidence, incidences) {
         const Akonadi::Item existingItem = calendar()->item(incidence);
-        const bool existsInSameCollection = existingItem.isValid()
-                                            && (existingItem.storageCollectionId()
-                                                == collectionId() || collectionId() == -1);
+        const bool existsInSameCollection
+            = existingItem.isValid()
+              && (existingItem.storageCollectionId() == collectionId() || collectionId() == -1);
 
         if (existingItem.isValid() && existsInSameCollection) {
             KCalCore::Incidence::Ptr newIncidence
@@ -2300,8 +2299,9 @@ void AgendaView::alignAgendas()
 {
     // resize dummy widget so the allday agenda lines up with the hourly agenda.
     if (d->mDummyAllDayLeft) {
-        d->mDummyAllDayLeft->setFixedWidth(-SPACING + d->mTimeLabelsZone->width()
-                                           -d->mTimeBarHeaderFrame->width());
+        d->mDummyAllDayLeft->setFixedWidth(d->mTimeLabelsZone->width()
+                                           -d->mTimeBarHeaderFrame->width()
+                                           -SPACING);
     }
 
     // Must be async, so they are centered
